@@ -1,10 +1,8 @@
 	
-findTMS <- function (x, span, sn, thresh = 0.2) {
+findTMS <- function (x, span, sn, thresh = 0.2, debug = FALSE) {
 	
 	# Part of ChemoSpec, December 2012, Bryan A. Hanson
-	
-	# local helper function
-	
+		
 	pp <- function (x, span) {
 	# Borrowed from ChemometricsWithR by R. Wehrens
     span.width <- span * 2 + 1
@@ -15,6 +13,8 @@ findTMS <- function (x, span, sn, thresh = 0.2) {
     unique(pks[!is.na(pks)])
 		}
 
+	if (debug) cat("\tfindTMS is looking around for TMS or TSP")
+	
 	peaks <- pp(x, span) # get all peaks by index in x, then calc SN
 	thresh <- quantile(x > 0, thresh)
 	keep <- which(x[peaks] >= thresh) # important to only look at large positive peaks
