@@ -1,5 +1,4 @@
-hmapSpectra <- function(spectra, no.col = 5, title = "no title provided",
-	t.pos = c(0.5, 0.5, 0.5), cexRow = 1, cexCol = 1, ...) {
+hmapSpectra <- function(spectra, no.col = 5, cexRow = 1, cexCol = 1, ...) {
 	
 	# Function to display heat map of
 	# seriated HCA
@@ -14,6 +13,6 @@ hmapSpectra <- function(spectra, no.col = 5, title = "no title provided",
 		xlab = x.lab, ylab = "",
 		control = list(margin = 2),
 		options = list(col = brewer.pal(no.col, "Set1")),
-		cexRow = cexRow, cexCol = cexCol)
-	text(x = t.pos[1], y = t.pos[2], adj = t.pos[3], labels = title, cex = 1.5)
+		cexRow = cexRow, cexCol = cexCol, ...)
+#	text(x = t.pos[1], y = t.pos[2], adj = t.pos[3], labels = title, cex = 1.5)
 	}
\ No newline at end of file
